Class: Aws::CloudWatchEvents::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudWatchEvents::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudwatchevents/client.rb,
sig/client.rbs
Overview
An API client for CloudWatchEvents. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudWatchEvents::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelReplayResponseSuccess, _CreateApiDestinationResponseSuccess, _CreateArchiveResponseSuccess, _CreateConnectionResponseSuccess, _CreateEventBusResponseSuccess, _CreatePartnerEventSourceResponseSuccess, _DeauthorizeConnectionResponseSuccess, _DeleteApiDestinationResponseSuccess, _DeleteArchiveResponseSuccess, _DeleteConnectionResponseSuccess, _DescribeApiDestinationResponseSuccess, _DescribeArchiveResponseSuccess, _DescribeConnectionResponseSuccess, _DescribeEventBusResponseSuccess, _DescribeEventSourceResponseSuccess, _DescribePartnerEventSourceResponseSuccess, _DescribeReplayResponseSuccess, _DescribeRuleResponseSuccess, _ListApiDestinationsResponseSuccess, _ListArchivesResponseSuccess, _ListConnectionsResponseSuccess, _ListEventBusesResponseSuccess, _ListEventSourcesResponseSuccess, _ListPartnerEventSourceAccountsResponseSuccess, _ListPartnerEventSourcesResponseSuccess, _ListReplaysResponseSuccess, _ListRuleNamesByTargetResponseSuccess, _ListRulesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetsByRuleResponseSuccess, _PutEventsResponseSuccess, _PutPartnerEventsResponseSuccess, _PutRuleResponseSuccess, _PutTargetsResponseSuccess, _RemoveTargetsResponseSuccess, _StartReplayResponseSuccess, _TagResourceResponseSuccess, _TestEventPatternResponseSuccess, _UntagResourceResponseSuccess, _UpdateApiDestinationResponseSuccess, _UpdateArchiveResponseSuccess, _UpdateConnectionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_event_source(params = {}) ⇒ Struct
Activates a partner event source that has been deactivated.
-
#cancel_replay(params = {}) ⇒ Types::CancelReplayResponse
Cancels the specified replay.
-
#create_api_destination(params = {}) ⇒ Types::CreateApiDestinationResponse
Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.
-
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates an archive of events with the specified settings.
-
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection.
-
#create_event_bus(params = {}) ⇒ Types::CreateEventBusResponse
Creates a new event bus within your account.
-
#create_partner_event_source(params = {}) ⇒ Types::CreatePartnerEventSourceResponse
Called by an SaaS partner to create a partner event source.
-
#deactivate_event_source(params = {}) ⇒ Struct
You can use this operation to temporarily stop receiving events from the specified partner event source.
-
#deauthorize_connection(params = {}) ⇒ Types::DeauthorizeConnectionResponse
Removes all authorization parameters from the connection.
-
#delete_api_destination(params = {}) ⇒ Struct
Deletes the specified API destination.
-
#delete_archive(params = {}) ⇒ Struct
Deletes the specified archive.
-
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes a connection.
-
#delete_event_bus(params = {}) ⇒ Struct
Deletes the specified custom event bus or partner event bus.
-
#delete_partner_event_source(params = {}) ⇒ Struct
This operation is used by SaaS partners to delete a partner event source.
-
#delete_rule(params = {}) ⇒ Struct
Deletes the specified rule.
-
#describe_api_destination(params = {}) ⇒ Types::DescribeApiDestinationResponse
Retrieves details about an API destination.
-
#describe_archive(params = {}) ⇒ Types::DescribeArchiveResponse
Retrieves details about an archive.
-
#describe_connection(params = {}) ⇒ Types::DescribeConnectionResponse
Retrieves details about a connection.
-
#describe_event_bus(params = {}) ⇒ Types::DescribeEventBusResponse
Displays details about an event bus in your account.
-
#describe_event_source(params = {}) ⇒ Types::DescribeEventSourceResponse
This operation lists details about a partner event source that is shared with your account.
-
#describe_partner_event_source(params = {}) ⇒ Types::DescribePartnerEventSourceResponse
An SaaS partner can use this operation to list details about a partner event source that they have created.
-
#describe_replay(params = {}) ⇒ Types::DescribeReplayResponse
Retrieves details about a replay.
-
#describe_rule(params = {}) ⇒ Types::DescribeRuleResponse
Describes the specified rule.
-
#disable_rule(params = {}) ⇒ Struct
Disables the specified rule.
-
#enable_rule(params = {}) ⇒ Struct
Enables the specified rule.
-
#list_api_destinations(params = {}) ⇒ Types::ListApiDestinationsResponse
Retrieves a list of API destination in the account in the current Region.
-
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Lists your archives.
-
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Retrieves a list of connections from the account.
-
#list_event_buses(params = {}) ⇒ Types::ListEventBusesResponse
Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.
-
#list_event_sources(params = {}) ⇒ Types::ListEventSourcesResponse
You can use this to see all the partner event sources that have been shared with your Amazon Web Services account.
-
#list_partner_event_source_accounts(params = {}) ⇒ Types::ListPartnerEventSourceAccountsResponse
An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with.
-
#list_partner_event_sources(params = {}) ⇒ Types::ListPartnerEventSourcesResponse
An SaaS partner can use this operation to list all the partner event source names that they have created.
-
#list_replays(params = {}) ⇒ Types::ListReplaysResponse
Lists your replays.
-
#list_rule_names_by_target(params = {}) ⇒ Types::ListRuleNamesByTargetResponse
Lists the rules for the specified target.
-
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists your Amazon EventBridge rules.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an EventBridge resource.
-
#list_targets_by_rule(params = {}) ⇒ Types::ListTargetsByRuleResponse
Lists the targets assigned to the specified rule.
-
#put_events(params = {}) ⇒ Types::PutEventsResponse
Sends custom events to Amazon EventBridge so that they can be matched to rules.
-
#put_partner_events(params = {}) ⇒ Types::PutPartnerEventsResponse
This is used by SaaS partners to write events to a customer's partner event bus.
-
#put_permission(params = {}) ⇒ Struct
Running
PutPermissionpermits the specified Amazon Web Services account or Amazon Web Services organization to put events to the specified event bus. -
#put_rule(params = {}) ⇒ Types::PutRuleResponse
Creates or updates the specified rule.
-
#put_targets(params = {}) ⇒ Types::PutTargetsResponse
Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule.
-
#remove_permission(params = {}) ⇒ Struct
Revokes the permission of another Amazon Web Services account to be able to put events to the specified event bus.
-
#remove_targets(params = {}) ⇒ Types::RemoveTargetsResponse
Removes the specified targets from the specified rule.
-
#start_replay(params = {}) ⇒ Types::StartReplayResponse
Starts the specified replay.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge resource.
-
#test_event_pattern(params = {}) ⇒ Types::TestEventPatternResponse
Tests whether the specified event pattern matches the provided event.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge resource.
-
#update_api_destination(params = {}) ⇒ Types::UpdateApiDestinationResponse
Updates an API destination.
-
#update_archive(params = {}) ⇒ Types::UpdateArchiveResponse
Updates the specified archive.
-
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates settings for a connection.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-cloudwatchevents/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3478 3479 3480 |
# File 'lib/aws-sdk-cloudwatchevents/client.rb', line 3478 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3481 3482 3483 |
# File 'lib/aws-sdk-cloudwatchevents/client.rb', line 3481 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#activate_event_source(params = {}) ⇒ Struct
Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.
83 |
# File 'sig/client.rbs', line 83
def activate_event_source: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-cloudwatchevents/client.rb', line 3451 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudWatchEvents') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudwatchevents' context[:gem_version] = '1.108.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_replay(params = {}) ⇒ Types::CancelReplayResponse
Cancels the specified replay.
95 |
# File 'sig/client.rbs', line 95
def cancel_replay: (
|
#create_api_destination(params = {}) ⇒ Types::CreateApiDestinationResponse
Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.
108 |
# File 'sig/client.rbs', line 108
def create_api_destination: (
|
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates an archive of events with the specified settings. When you create an archive, incoming events might not immediately start being sent to the archive. Allow a short period of time for changes to take effect. If you do not specify a pattern to filter events sent to the archive, all events are sent to the archive except replayed events. Replayed events are not sent to an archive.
126 |
# File 'sig/client.rbs', line 126
def create_archive: (
|
#create_connection(params = {}) ⇒ Types::CreateConnectionResponse
Creates a connection. A connection defines the authorization type and credentials to use for authorization with an API destination HTTP endpoint.
143 |
# File 'sig/client.rbs', line 143
def create_connection: (
|
#create_event_bus(params = {}) ⇒ Types::CreateEventBusResponse
Creates a new event bus within your account. This can be a custom event bus which you can use to receive events from your custom applications and services, or it can be a partner event bus which can be matched to a partner event source.
175 |
# File 'sig/client.rbs', line 175
def create_event_bus: (
|
#create_partner_event_source(params = {}) ⇒ Types::CreatePartnerEventSourceResponse
Called by an SaaS partner to create a partner event source. This operation is not used by Amazon Web Services customers.
Each partner event source can be used by one Amazon Web Services account to create a matching partner event bus in that Amazon Web Services account. A SaaS partner must create one partner event source for each Amazon Web Services account that wants to receive those event types.
A partner event source creates events based on resources within the SaaS partner's service or application.
An Amazon Web Services account that creates a partner event bus that matches the partner event source can use that event bus to receive events from the partner, and then process them using Amazon Web Services Events rules and targets.
Partner event source names follow this format:
partner_name/event_namespace/event_name
partner_name is determined during partner registration and identifies the partner to Amazon Web Services customers. event_namespace is determined by the partner and is a way for the partner to categorize their events. event_name is determined by the partner, and should uniquely identify an event-generating resource within the partner system. The combination of event_namespace and event_name should help Amazon Web Services customers decide whether to create an event bus to receive these events.
192 |
# File 'sig/client.rbs', line 192
def create_partner_event_source: (
|
#deactivate_event_source(params = {}) ⇒ Struct
You can use this operation to temporarily stop receiving events from the specified partner event source. The matching event bus is not deleted.
When you deactivate a partner event source, the source goes into PENDING state. If it remains in PENDING state for more than two weeks, it is deleted.
To activate a deactivated partner event source, use ActivateEventSource.
199 |
# File 'sig/client.rbs', line 199
def deactivate_event_source: (
|
#deauthorize_connection(params = {}) ⇒ Types::DeauthorizeConnectionResponse
Removes all authorization parameters from the connection. This lets you remove the secret from the connection so you can reuse it without having to create a new connection.
213 |
# File 'sig/client.rbs', line 213
def deauthorize_connection: (
|
#delete_api_destination(params = {}) ⇒ Struct
Deletes the specified API destination.
222 |
# File 'sig/client.rbs', line 222
def delete_api_destination: (
|
#delete_archive(params = {}) ⇒ Struct
Deletes the specified archive.
231 |
# File 'sig/client.rbs', line 231
def delete_archive: (
|
#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse
Deletes a connection.
245 |
# File 'sig/client.rbs', line 245
def delete_connection: (
|
#delete_event_bus(params = {}) ⇒ Struct
Deletes the specified custom event bus or partner event bus. All rules associated with this event bus need to be deleted. You can't delete your account's default event bus.
251 |
# File 'sig/client.rbs', line 251
def delete_event_bus: (
|
#delete_partner_event_source(params = {}) ⇒ Struct
This operation is used by SaaS partners to delete a partner event source. This operation is not used by Amazon Web Services customers.
When you delete an event source, the status of the corresponding partner event bus in the Amazon Web Services customer account becomes DELETED.
257 |
# File 'sig/client.rbs', line 257
def delete_partner_event_source: (
|
#delete_rule(params = {}) ⇒ Struct
Deletes the specified rule.
Before you can delete the rule, you must remove all targets, using RemoveTargets.
When you delete a rule, incoming events might continue to match to the deleted rule. Allow a short period of time for changes to take effect.
If you call delete rule multiple times for the same rule, all calls
will succeed. When you call delete rule for a non-existent custom
eventbus, ResourceNotFoundException is returned.
Managed rules are rules created and managed by another Amazon Web
Services service on your behalf. These rules are created by those
other Amazon Web Services services to support functionality in those
services. You can delete these rules using the Force option, but you
should do so only if you are sure the other service is not still using
that rule.
264 |
# File 'sig/client.rbs', line 264
def delete_rule: (
|
#describe_api_destination(params = {}) ⇒ Types::DescribeApiDestinationResponse
Retrieves details about an API destination.
285 |
# File 'sig/client.rbs', line 285
def describe_api_destination: (
|
#describe_archive(params = {}) ⇒ Types::DescribeArchiveResponse
Retrieves details about an archive.
305 |
# File 'sig/client.rbs', line 305
def describe_archive: (
|
#describe_connection(params = {}) ⇒ Types::DescribeConnectionResponse
Retrieves details about a connection.
325 |
# File 'sig/client.rbs', line 325
def describe_connection: (
|
#describe_event_bus(params = {}) ⇒ Types::DescribeEventBusResponse
Displays details about an event bus in your account. This can include the external Amazon Web Services accounts that are permitted to write events to your default event bus, and the associated policy. For custom event buses and partner event buses, it displays the name, ARN, policy, state, and creation time.
To enable your account to receive events from other accounts on its default event bus, use PutPermission.
For more information about partner event buses, see CreateEventBus.
337 |
# File 'sig/client.rbs', line 337
def describe_event_bus: (
|
#describe_event_source(params = {}) ⇒ Types::DescribeEventSourceResponse
This operation lists details about a partner event source that is shared with your account.
352 |
# File 'sig/client.rbs', line 352
def describe_event_source: (
|
#describe_partner_event_source(params = {}) ⇒ Types::DescribePartnerEventSourceResponse
An SaaS partner can use this operation to list details about a partner event source that they have created. Amazon Web Services customers do not use this operation. Instead, Amazon Web Services customers can use DescribeEventSource to see details about a partner event source that is shared with them.
363 |
# File 'sig/client.rbs', line 363
def describe_partner_event_source: (
|
#describe_replay(params = {}) ⇒ Types::DescribeReplayResponse
Retrieves details about a replay. Use DescribeReplay to determine
the progress of a running replay. A replay processes events to replay
based on the time in the event, and replays them using 1 minute
intervals. If you use StartReplay and specify an EventStartTime
and an EventEndTime that covers a 20 minute time range, the events
are replayed from the first minute of that 20 minute range first. Then
the events from the second minute are replayed. You can use
DescribeReplay to determine the progress of a replay. The value
returned for EventLastReplayedTime indicates the time within the
specified time range associated with the last event replayed.
384 |
# File 'sig/client.rbs', line 384
def describe_replay: (
|
#describe_rule(params = {}) ⇒ Types::DescribeRuleResponse
Describes the specified rule.
DescribeRule does not list the targets of a rule. To see the targets associated with a rule, use ListTargetsByRule.
403 |
# File 'sig/client.rbs', line 403
def describe_rule: (
|
#disable_rule(params = {}) ⇒ Struct
Disables the specified rule. A disabled rule won't match any events, and won't self-trigger if it has a schedule expression.
When you disable a rule, incoming events might continue to match to the disabled rule. Allow a short period of time for changes to take effect.
410 |
# File 'sig/client.rbs', line 410
def disable_rule: (
|
#enable_rule(params = {}) ⇒ Struct
Enables the specified rule. If the rule does not exist, the operation fails.
When you enable a rule, incoming events might not immediately start matching to a newly enabled rule. Allow a short period of time for changes to take effect.
417 |
# File 'sig/client.rbs', line 417
def enable_rule: (
|
#list_api_destinations(params = {}) ⇒ Types::ListApiDestinationsResponse
Retrieves a list of API destination in the account in the current Region.
429 |
# File 'sig/client.rbs', line 429
def list_api_destinations: (
|
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Lists your archives. You can either list all the archives or you can provide a prefix to match to the archive names. Filter parameters are exclusive.
443 |
# File 'sig/client.rbs', line 443
def list_archives: (
|
#list_connections(params = {}) ⇒ Types::ListConnectionsResponse
Retrieves a list of connections from the account.
458 |
# File 'sig/client.rbs', line 458
def list_connections: (
|
#list_event_buses(params = {}) ⇒ Types::ListEventBusesResponse
Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.
472 |
# File 'sig/client.rbs', line 472
def list_event_buses: (
|
#list_event_sources(params = {}) ⇒ Types::ListEventSourcesResponse
You can use this to see all the partner event sources that have been shared with your Amazon Web Services account. For more information about partner event sources, see CreateEventBus.
485 |
# File 'sig/client.rbs', line 485
def list_event_sources: (
|
#list_partner_event_source_accounts(params = {}) ⇒ Types::ListPartnerEventSourceAccountsResponse
An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with. This operation is not used by Amazon Web Services customers.
498 |
# File 'sig/client.rbs', line 498
def list_partner_event_source_accounts: (
|
#list_partner_event_sources(params = {}) ⇒ Types::ListPartnerEventSourcesResponse
An SaaS partner can use this operation to list all the partner event source names that they have created. This operation is not used by Amazon Web Services customers.
511 |
# File 'sig/client.rbs', line 511
def list_partner_event_sources: (
|
#list_replays(params = {}) ⇒ Types::ListReplaysResponse
Lists your replays. You can either list all the replays or you can provide a prefix to match to the replay names. Filter parameters are exclusive.
524 |
# File 'sig/client.rbs', line 524
def list_replays: (
|
#list_rule_names_by_target(params = {}) ⇒ Types::ListRuleNamesByTargetResponse
Lists the rules for the specified target. You can see which of the rules in Amazon EventBridge can invoke a specific target in your account.
539 |
# File 'sig/client.rbs', line 539
def list_rule_names_by_target: (
|
#list_rules(params = {}) ⇒ Types::ListRulesResponse
Lists your Amazon EventBridge rules. You can either list all the rules or you can provide a prefix to match to the rule names.
ListRules does not list the targets of a rule. To see the targets associated with a rule, use ListTargetsByRule.
553 |
# File 'sig/client.rbs', line 553
def list_rules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with an EventBridge resource. In EventBridge, rules and event buses can be tagged.
566 |
# File 'sig/client.rbs', line 566
def list_tags_for_resource: (
|
#list_targets_by_rule(params = {}) ⇒ Types::ListTargetsByRuleResponse
Lists the targets assigned to the specified rule.
577 |
# File 'sig/client.rbs', line 577
def list_targets_by_rule: (
|
#put_events(params = {}) ⇒ Types::PutEventsResponse
Sends custom events to Amazon EventBridge so that they can be matched to rules.
591 |
# File 'sig/client.rbs', line 591
def put_events: (
|
#put_partner_events(params = {}) ⇒ Types::PutPartnerEventsResponse
This is used by SaaS partners to write events to a customer's partner event bus. Amazon Web Services customers do not use this operation.
612 |
# File 'sig/client.rbs', line 612
def put_partner_events: (
|
#put_permission(params = {}) ⇒ Struct
Running PutPermission permits the specified Amazon Web Services
account or Amazon Web Services organization to put events to the
specified event bus. Amazon EventBridge (CloudWatch Events) rules in
your account are triggered by these events arriving to an event bus in
your account.
For another account to send events to your account, that external account must have an EventBridge rule with your account's event bus as a target.
To enable multiple Amazon Web Services accounts to put events to your
event bus, run PutPermission once for each of these accounts. Or, if
all the accounts are members of the same Amazon Web Services
organization, you can run PutPermission once specifying Principal
as "*" and specifying the Amazon Web Services organization ID in
Condition, to grant permissions to all accounts in that
organization.
If you grant permissions using an organization, then accounts in that
organization must specify a RoleArn with proper permissions when
they use PutTarget to add your account's event bus as a target. For
more information, see Sending and Receiving Events Between Amazon Web
Services Accounts in the Amazon EventBridge User Guide.
The permission policy on the event bus cannot exceed 10 KB in size.
626 |
# File 'sig/client.rbs', line 626
def put_permission: (
|
#put_rule(params = {}) ⇒ Types::PutRuleResponse
Creates or updates the specified rule. Rules are enabled by default, or based on value of the state. You can disable a rule using DisableRule.
A single rule watches for events from a single event bus. Events generated by Amazon Web Services services go to your account's default event bus. Events generated by SaaS partner services or applications go to the matching partner event bus. If you have custom applications or services, you can specify whether their events go to your default event bus or a custom event bus that you have created. For more information, see CreateEventBus.
If you are updating an existing rule, the rule is replaced with what
you specify in this PutRule command. If you omit arguments in
PutRule, the old values for those arguments are not kept. Instead,
they are replaced with null values.
When you create or update a rule, incoming events might not immediately start matching to new or updated rules. Allow a short period of time for changes to take effect.
A rule must contain at least an EventPattern or ScheduleExpression. Rules with EventPatterns are triggered when a matching event is observed. Rules with ScheduleExpressions self-trigger based on the given schedule. A rule can have both an EventPattern and a ScheduleExpression, in which case the rule triggers on matching events as well as on a schedule.
When you initially create a rule, you can optionally assign one or
more tags to the rule. Tags can help you organize and categorize your
resources. You can also use them to scope user permissions, by
granting a user permission to access or change only rules with certain
tag values. To use the PutRule operation and assign tags, you must
have both the events:PutRule and events:TagResource permissions.
If you are updating an existing rule, any tags you specify in the
PutRule operation are ignored. To update the tags of an existing
rule, use TagResource and UntagResource.
Most services in Amazon Web Services treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.
In EventBridge, it is possible to create rules that lead to infinite loops, where a rule is fired repeatedly. For example, a rule might detect that ACLs have changed on an S3 bucket, and trigger software to change them to the desired state. If the rule is not written carefully, the subsequent change to the ACLs fires the rule again, creating an infinite loop.
To prevent this, write the rules so that the triggered actions do not re-fire the same rule. For example, your rule could fire only if ACLs are found to be in a bad state, instead of after any change.
An infinite loop can quickly cause higher than expected charges. We recommend that you use budgeting, which alerts you when charges exceed your specified limit. For more information, see Managing Your Costs with Budgets.
645 |
# File 'sig/client.rbs', line 645
def put_rule: (
|
#put_targets(params = {}) ⇒ Types::PutTargetsResponse
Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule.
Targets are the resources that are invoked when a rule is triggered.
You can configure the following as targets for Events:
-
Amazon API Gateway REST API endpoints
-
API Gateway
-
Batch job queue
-
CloudWatch Logs group
-
CodeBuild project
-
CodePipeline
-
Amazon EC2
CreateSnapshotAPI call -
Amazon EC2
RebootInstancesAPI call -
Amazon EC2
StopInstancesAPI call -
Amazon EC2
TerminateInstancesAPI call -
Amazon ECS tasks
-
Event bus in a different Amazon Web Services account or Region.
You can use an event bus in the US East (N. Virginia) us-east-1, US West (Oregon) us-west-2, or Europe (Ireland) eu-west-1 Regions as a target for a rule.
-
Firehose delivery stream (Firehose)
-
Inspector assessment template (Amazon Inspector)
-
Kinesis stream (Kinesis Data Stream)
-
Lambda function
-
Redshift clusters (Data API statement execution)
-
Amazon SNS topic
-
Amazon SQS queues (includes FIFO queues
-
SSM Automation
-
SSM OpsItem
-
SSM Run Command
-
Step Functions state machines
Creating rules with built-in targets is supported only in the Amazon
Web Services Management Console. The built-in targets are EC2 CreateSnapshot API call, EC2 RebootInstances API call, EC2 StopInstances API call, and EC2 TerminateInstances API call.
For some target types, PutTargets provides target-specific
parameters. If the target is a Kinesis data stream, you can optionally
specify which shard the event goes to by using the KinesisParameters
argument. To invoke a command on multiple EC2 instances with one rule,
you can use the RunCommandParameters field.
To be able to make API calls against the resources that you own,
Amazon EventBridge needs the appropriate permissions. For Lambda and
Amazon SNS resources, EventBridge relies on resource-based policies.
For EC2 instances, Kinesis Data Streams, Step Functions state machines
and API Gateway REST APIs, EventBridge relies on IAM roles that you
specify in the RoleARN argument in PutTargets. For more
information, see Authentication and Access Control in the Amazon
EventBridge User Guide.
If another Amazon Web Services account is in the same region and has
granted you permission (using PutPermission), you can send events to
that account. Set that account's event bus as a target of the rules
in your account. To send the matched events to the other account,
specify that account's event bus as the Arn value when you run
PutTargets. If your account sends events to another account, your
account is charged for each sent event. Each event sent to another
account is charged as a custom event. The account receiving the event
is not charged. For more information, see Amazon EventBridge
Pricing.
Input, InputPath, and InputTransformer are not available with
PutTarget if the target is an event bus of a different Amazon Web
Services account.
If you are setting the event bus of another account as the target, and
that account granted permission to your account through an
organization instead of directly by the account ID, then you must
specify a RoleArn with proper permissions in the Target structure.
For more information, see Sending and Receiving Events Between Amazon
Web Services Accounts in the Amazon EventBridge User Guide.
For more information about enabling cross-account events, see PutPermission.
Input, InputPath, and InputTransformer are mutually exclusive and optional parameters of a target. When a rule is triggered due to a matched event:
-
If none of the following arguments are specified for a target, then the entire event is passed to the target in JSON format (unless the target is Amazon EC2 Run Command or Amazon ECS task, in which case nothing from the event is passed to the target).
-
If Input is specified in the form of valid JSON, then the matched event is overridden with this constant.
-
If InputPath is specified in the form of JSONPath (for example,
$.detail), then only the part of the event specified in the path is passed to the target (for example, only the detail part of the event is passed). -
If InputTransformer is specified, then one or more specified JSONPaths are extracted from the event and used as values in a template that you specify as the input to the target.
When you specify InputPath or InputTransformer, you must use JSON
dot notation, not bracket notation.
When you add targets to a rule and the associated rule triggers soon after, new or updated targets might not be immediately invoked. Allow a short period of time for changes to take effect.
This action can partially fail if too many requests are made at the
same time. If that happens, FailedEntryCount is non-zero in the
response and each entry in FailedEntries provides the ID of the
failed target and the error code.
668 |
# File 'sig/client.rbs', line 668
def put_targets: (
|
#remove_permission(params = {}) ⇒ Struct
Revokes the permission of another Amazon Web Services account to be
able to put events to the specified event bus. Specify the account to
revoke by the StatementId value that you associated with the account
when you granted it permission with PutPermission. You can find the
StatementId by using DescribeEventBus.
783 |
# File 'sig/client.rbs', line 783
def remove_permission: (
|
#remove_targets(params = {}) ⇒ Types::RemoveTargetsResponse
Removes the specified targets from the specified rule. When the rule is triggered, those targets are no longer be invoked.
When you remove a target, when the associated rule triggers, removed targets might continue to be invoked. Allow a short period of time for changes to take effect.
This action can partially fail if too many requests are made at the
same time. If that happens, FailedEntryCount is non-zero in the
response and each entry in FailedEntries provides the ID of the
failed target and the error code.
796 |
# File 'sig/client.rbs', line 796
def remove_targets: (
|
#start_replay(params = {}) ⇒ Types::StartReplayResponse
Starts the specified replay. Events are not necessarily replayed in
the exact same order that they were added to the archive. A replay
processes events to replay based on the time in the event, and replays
them using 1 minute intervals. If you specify an EventStartTime and
an EventEndTime that covers a 20 minute time range, the events are
replayed from the first minute of that 20 minute range first. Then the
events from the second minute are replayed. You can use
DescribeReplay to determine the progress of a replay. The value
returned for EventLastReplayedTime indicates the time within the
specified time range associated with the last event replayed.
812 |
# File 'sig/client.rbs', line 812
def start_replay: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge resource. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. In EventBridge, rules and event buses can be tagged.
Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the TagResource action with a resource that already has
tags. If you specify a new tag key, this tag is appended to the list
of tags associated with the resource. If you specify a tag key that is
already associated with the resource, the new tag value that you
specify replaces the previous value for that tag.
You can associate as many as 50 tags with a resource.
829 |
# File 'sig/client.rbs', line 829
def tag_resource: (
|
#test_event_pattern(params = {}) ⇒ Types::TestEventPatternResponse
Tests whether the specified event pattern matches the provided event.
Most services in Amazon Web Services treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.
845 |
# File 'sig/client.rbs', line 845
def test_event_pattern: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge resource. In Amazon EventBridge (CloudWatch Events), rules and event buses can be tagged.
855 |
# File 'sig/client.rbs', line 855
def untag_resource: (
|
#update_api_destination(params = {}) ⇒ Types::UpdateApiDestinationResponse
Updates an API destination.
869 |
# File 'sig/client.rbs', line 869
def update_api_destination: (
|
#update_archive(params = {}) ⇒ Types::UpdateArchiveResponse
Updates the specified archive.
887 |
# File 'sig/client.rbs', line 887
def update_archive: (
|
#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse
Updates settings for a connection.
904 |
# File 'sig/client.rbs', line 904
def update_connection: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3471 3472 3473 |
# File 'lib/aws-sdk-cloudwatchevents/client.rb', line 3471 def waiter_names [] end |