Class: Aws::CloudWatchEvents::Types::ListRuleNamesByTargetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchevents/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_bus_nameString

The name or ARN of the event bus to list rules for. If you omit this, the default event bus is used.



2539
2540
2541
2542
2543
2544
2545
2546
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 2539

class ListRuleNamesByTargetRequest < Struct.new(
  :target_arn,
  :event_bus_name,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of results to return.



2539
2540
2541
2542
2543
2544
2545
2546
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 2539

class ListRuleNamesByTargetRequest < Struct.new(
  :target_arn,
  :event_bus_name,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token returned by a previous call to retrieve the next set of results.



2539
2540
2541
2542
2543
2544
2545
2546
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 2539

class ListRuleNamesByTargetRequest < Struct.new(
  :target_arn,
  :event_bus_name,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) of the target resource.



2539
2540
2541
2542
2543
2544
2545
2546
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 2539

class ListRuleNamesByTargetRequest < Struct.new(
  :target_arn,
  :event_bus_name,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end