Class: Aws::CloudWatchEvents::Types::ReplayDestination

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchevents/types.rb

Overview

A ReplayDestination object that contains details about a replay.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the event bus to replay event to. You can replay events only to the event bus specified to create the archive.



3505
3506
3507
3508
3509
3510
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 3505

class ReplayDestination < Struct.new(
  :arn,
  :filter_arns)
  SENSITIVE = []
  include Aws::Structure
end

#filter_arnsArray<String>

A list of ARNs for rules to replay events to.



3505
3506
3507
3508
3509
3510
# File 'lib/aws-sdk-cloudwatchevents/types.rb', line 3505

class ReplayDestination < Struct.new(
  :arn,
  :filter_arns)
  SENSITIVE = []
  include Aws::Structure
end